#
# spec file for package gkrellm
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gkrellm
Version:        2.3.11
Release:        4.1
Summary:        Manages Multiple Stacked Monitors
License:        GPL-3.0-or-later
Group:          System/Monitoring
URL:            http://gkrellm.srcbox.net/
Source:         http://gkrellm.srcbox.net/releases/%{name}-%{version}.tar.bz2
Source1:        %name.desktop
Source2:        gkrellm-16.png
Source3:        gkrellm-24.png
Source4:        gkrellm-32.png
Source5:        gkrellm-48.png
%if 0%{?suse_version} > 1220
Source6:        gkrellmd.service
%endif
# PATCH-FIX-OPENSUSE gkrellm-lib64-plugins-dir.patch pgajdos@suse.cz -- look also into /usr/lib64/gkrellm2/plugins
Patch1:         %{name}-lib64-plugins-dir.patch
# PATCH-FIX-OPENSUSE gkrellm-install-and-reconnect-gkrellmd.conf.patch hpj@urpla.net -- install /etc/gkrellmd.conf and make reconnect default
Patch2:         %{name}-install-and-reconnect-gkrellmd.conf.patch

BuildRequires:  gtk2-devel
BuildRequires:  libsensors4-devel
%if 0%{?suse_version} > 1220
BuildRequires:  systemd-rpm-macros
%endif
BuildRequires:  openssl-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-libSM-devel
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# no libsensors
ExcludeArch:    s390 s390x

%description
With a single process, GKrellM manages multiple stacked monitors and
supports applying themes to match the monitors appearance to your
window manager, Gtk, or any other theme.

* SMP CPU, Disk, Proc, and active net interface monitors with LEDs.

* Internet monitor that displays current and charts historical port
   hits.

* Memory and swap space usage meters and a system uptime monitor.

* File system meters show capacity and free space and can mount and
   umount.

* A mailbox monitor that can launch a mail reader and fetch remote
   mail.

* Clock, calendar, and hostname display.

* APM laptop battery monitor.

* CPU and motherboard temperature display if lm_sensors modules are
   installed.

* Multiple monitors managed by a single process to reduce system
   load.

* PPP on and off button that can execute your PPP scripts.

* Charts are autoscaling with configurable grid line resolution.

* Separate colors for "in" and "out" data.  The in color is used for
   CPU user time, disk read, forks, and net receive data.  The out
   color is used for CPU sys time, disk write, load, and net
   transmit data.

* A different theme can be created with the GIMP.

%package -n gkrellmd
Summary:        Multiple Stacked Monitors daemon
Group:          System/Monitoring

%description -n gkrellmd
The GNU Grell Monitors daemon service, independent from any GUI library.

%package devel
Summary:        Files needed for gkrellm2 development
Group:          Development/Sources
Requires:       gkrellm = %{version}

%description devel
Files needed to build plugins for gkrellm2

%lang_package

%prep
%autosetup -p1

%build
cd src
# run configure to build against libsensors; otherwise it leads to
#e. g. bnc#803967 bnc#803081
./configure
cd ..
make CFLAGS="%{optflags}" X11_LIBS="-L/usr/X11R6/%{_lib} -lX11 -lSM -lICE" GTOP_LIBS="-lgmodule-2.0" PREFIX=%{_prefix}

%install
make install STRIP= \
     X11_LIBS="-L/usr/X11R6/%{_lib} -lX11 -lSM -lICE" \
     INSTALLROOT=%{buildroot}%{_prefix} \
     CFGDIR=%{buildroot}%{_sysconfdir} \
     PKGCONFIGDIR=%{buildroot}%{_libdir}/pkgconfig

for i in {16,24,32,48}; do
   mkdir -p %{buildroot}%{_datadir}/icons/hicolor/"$i"x"$i"/apps
done
cp %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/gkrellm.png
cp %{SOURCE3} %{buildroot}%{_datadir}/icons/hicolor/24x24/apps/gkrellm.png
cp %{SOURCE4} %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/gkrellm.png
cp %{SOURCE5} %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/gkrellm.png
# following two directories are searched for plugins and we want to own them (bnc#841818)
mkdir -p %{buildroot}/usr/lib/gkrellm2/plugins
%if "x%{_lib}" == "xlib64"
mkdir -p %{buildroot}/usr/lib64/gkrellm2/plugins
%endif
%if 0%{?suse_version} > 1220
install -D -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/gkrellmd.service
mkdir -p %{buildroot}%{_sbindir}
ln -s /sbin/service %{buildroot}%{_sbindir}/rcgkrellmd
%endif
%suse_update_desktop_file -i %name
%find_lang %{name} %{?no_lang_C}

%if 0%{?suse_version} > 1220
%pre -n gkrellmd
%service_add_pre gkrellmd.service
%endif

%post -n gkrellmd
%if 0%{?suse_version} > 1220
%service_add_post gkrellmd.service
%endif
%if 0%{?suse_version} > 1130
%desktop_database_post
%icon_theme_cache_post
%endif

%if %{?suse_version} > 1220
%preun -n gkrellmd
%service_del_preun gkrellmd.service
%stop_on_removal gkrellmd
%endif

%postun -n gkrellmd
%if 0%{?suse_version} > 1220
%service_del_postun gkrellmd.service
%restart_on_update gkrellmd
%endif
%if 0%{?suse_version} > 1130
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-,root,root)
%doc COPYRIGHT Changelog README Themes.html
%{_bindir}/gkrellm
%{_datadir}/icons/hicolor/*/apps/gkrellm.png
%{_datadir}/applications/gkrellm.desktop
%doc %{_mandir}/man1/*
%dir /usr/lib/gkrellm2
%dir /usr/lib/gkrellm2/plugins
%if "x%{_lib}" == "xlib64"
%dir /usr/lib64/gkrellm2
%dir /usr/lib64/gkrellm2/plugins
%endif

%files -n gkrellmd
%defattr(-,root,root)
%doc COPYRIGHT Changelog README Themes.html
%config(noreplace) %{_sysconfdir}/gkrellmd.conf
%{_bindir}/gkrellmd
%if 0%{?suse_version} > 1220
%{_sbindir}/rcgkrellmd
%{_unitdir}/gkrellmd.service
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/gkrellm2/
%{_libdir}/pkgconfig/gkrellm.pc

%files lang -f %{name}.lang

%changelog
* Tue Feb 18 2025 Andreas Stieger <andreas.stieger@gmx.de>
- fix bogus prefix / include path in Cflags (boo#1237310)
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Sep 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * gkrellmd.service
* Mon Nov 11 2019 Hans-Peter Jansen <hpj@urpla.net>
- updated to 2.3.11:
  * see http://git.srcbox.net/gkrellm/log/
- removed gkrellm-2.3.10-d51b57616e.patch (released upstream now)
* Wed Apr 17 2019 Hans-Peter Jansen <hpj@urpla.net>
- apply patch gkrellm-2.3.10-d51b57616e.patch with upstream git master
  changes, contains a number of important fixes, including improved
  gkrellm-2.3.5-fix-diskio-corruption.patch and
  gkrellm-2.3.5-fix-sdX-sort-order.patch
* Thu Nov 22 2018 Hans-Peter Jansen <hpj@urpla.net>
- add patch gkrellm-install-and-reconnect-gkrellmd.conf.patch
  in order to install /etc/gkrellmd.conf properly and make reconnect
  default
- refresh patches
* Thu Nov  8 2018 Hans-Peter Jansen <hpj@urpla.net>
- separate gkrellmd package
* Mon Dec 12 2016 dimstar@opensuse.org
- BuildRequire systemd-rpm-macros instead of
  pkgconfig(libsystemd-daemon): The libs is not used at all.
- Fix minor copy/paste error: run the post script for the right
  service name.
* Mon Nov 21 2016 pgajdos@suse.com
- updated to 2.3.10:
  * see http://git.srcbox.net/gkrellm/log/
- removed gkrellm-libsensors.patch (not needed, gkrellm links
  against libsensors correctly)
* Fri Mar 27 2015 seife+obs@b1-systems.com
- add gkrellm-2.3.5-fix-diskio-corruption.patch to fix corruption
  of chart labels (actually work around it)
* Sun Apr 27 2014 seife+obs@b1-systems.com
- add gkrellm-2.3.5-fix-sdX-sort-order.patch to fix sort order of
  sda,sdb,sdc,... disks
* Mon Feb 17 2014 pgajdos@suse.com
- Add systemd service gkrellm.service (bnc#864225).
* Wed Feb 12 2014 ro@suse.de
- Exclude s390/s390x that have no libsensors.
* Thu Oct 24 2013 pgajdos@suse.com
- Install /usr/lib{,64}/gkrellm2/plugins directories (bnc#841818).
- Add gkrellm-lib64-plugins-dir.patch: Look in
  /usr/lib64/gkrellm2/plugins on 64bit systems.
* Thu May  2 2013 schwab@linux-m68k.org
- Compile with %%{optflags}
* Tue Apr 23 2013 pgajdos@suse.com
- really build against libsensors [bnc#803967] and [bnc#803081]
* Tue Nov 20 2012 pgajdos@suse.com
- fixed url
* Mon Feb 20 2012 pgajdos@suse.com
- add xorg-x11-libSM-devel into buildrequires
* Wed Dec 21 2011 pgajdos@suse.com
- -lgmodule-2.0 added to the linker command line
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Split lang subpackage.
* Sat Oct  9 2010 vuntz@opensuse.org
- Update to version 2.3.5:
  + Linux sensors: check for /sys/class/thermal/thermal_zone[0-*].
  + Add Linux net monitor checking for IPv6 routes.
  + Use dynamic buffering to handle large disk names from a Mac
    gkrellmd.
  + Fix IMAP login by escaping backslash and double-quotes in
    username, password and mailbox strings.
  + Fix initial sending of fstab entries in gkrellmd, fstab was only
    sent if it was marked as "changed"
  + gkrellmd: Make "-d" commandline option the short version for
    "--detach" instead of for "--debug-level".
  + Add searching for linux sensors directly below hwmon dir since
    kernel is putting newer devices there.
  + Bugfixes
  - Fix eof check in fgets_pipe() (when using external mail check
    program).
  - Fix some aliasing violations due to sockaddr_* typecasting.
  + Code cleanups.
  + FreeBSD-related fixes.
  + Windows-related fixes.
  + Build fixes.
  + Updated translations.
- Rebase gkrellm-libsensors.patch to apply without fuzz.
- Change SMC_LIBS to X11_LIBS.
- Do not define CFLAGS and LOCALEDIR during the build: it's not
  needed anymore.
- Stop creating directories before installation: it's now handled
  properly by gkrellm.
- Do not set GenericName and Categories in gkrellm.desktop with
  %%suse_update_desktop_file, but instead set them directly in the
  file since we add it ourselves.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- Update to version 2.3.4:
  + Add gkrellm_sys_setup_connect() function so sysdep code can
    register from gkrellm_sys_main_init() a setup function to call
    after main() argument parsing
  + Add FreeBSD support for the amdtemp temperature sensor
  + Add some mbmon usage help to gkrellm.1 and README
  + Bugfixes
  - Patch from Sandro Tosi: fix a FTBFS when using gold as linker
    (by simply adding -lX11)
  - Add SSL library init calls to mail check for gnutls case
  - Patch from Hans de Goede: Fix some crashes - check for NULL
    GC when drawing root pixmap on transparent chart or panel
  - Patch from Goswin von Brederlow: Ignore device mapper devices
    in Linux disk stats
- Remove gkrellm-getline.patch. Fixed upstream
* Mon Nov 16 2009 seife@opensuse.org
- add devel package
* Fri Sep  4 2009 vuntz@novell.com
- Use spec-cleaner script to clean the packaging (mainly using the
  right macros for directories).
* Wed Aug 19 2009 beineri@opensuse.org
- add an already translated GenericName to .desktop file
- install an application menu icon
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid conflict with function
  from glibc
* Mon Jan 19 2009 pgajdos@suse.cz
- updated to 2.3.2:
  * Patch from Stefan Gehn:
  - Add error logging routines so errors and debugging can be routed to
    a file or stdout, and gkrellmd can log to the system syslog file.
    Begin replacing debug printf() with g_message(), g_warning(), etc
    functions to support the logging functions.
  - Port gtk_combo functions to gtk_combo_box
  - Add client mode server connection error dialog pupups.
  - Use GTK 2.12 gtk_widget_xxx_tooltip over gtk_tooltip in mail.c
  * Add OpenSSL license exception.
  Make OpenSSL the default to avoid gnutls symbol conflict crash.
  * Link to libntlm and remove smb* files from gkrellm source distribution.
  * Patch from Takao Fujiwara: Pass clock/calendar strings to strftime in
  current locale.  Bump default width up to 100.
  * Patch from Leo Schwab: add linux sysfs battery interface.  Use
  preferencially over deprecated /proc/acpi interface.
  * Patch from Lycestra:
  - Mac OS X support:
    "darwin9" build mode for Leopard, which lacks libkvm
    add inet monitor interface
  add buffers and cache data to memory monitor
  - don't client connect to server in the case read_server_setup() fails
  * Bugfixes
  o Allow spaces in file system monitor directories.
  o Andrey Rahmatullin and Ravi Pinjal both sent a patch to fix:
    some memleaks in clock monitor.
  o Ken Milmore patch: fix configure script to work for lm_sensors >= 3.1
  o NULL serve_name segfault
  * Translation updates
  o pl.po from Michal Smoczyk
- removed development files
* Thu Dec 18 2008 pgajdos@suse.cz
- build gkrellm againist libsensors
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang problems
* Tue Dec 11 2007 pgajdos@suse.cz
- upgrade to version 2.3.1
  * Clock/Calendar monitor rewritten to use user configurable display
  format strings containing strftime conversion characters and
  Pango text attribute markup strings.
  * dd new to be released libsensors4 interface to
  linux sensors.
  * -A option to bind gkrellmd to a specific interface.
  * Include UDP connections in the Linux inet monitor.
  * Bugfixes
  * Translation updates: de, fr, pl
* Sun Jul 22 2007 bwalle@suse.de
- Upgrade to version 2.3.0
  * Upgrade to GPLv3
  * mail check for Sylpheed .claws_mark mark file.
  * preserve config of disabled monitors.
  * look for linux I2O disks.
  * Don't save config for disabled non-existing net interfaces.
  * Add memory monitor raw free and raw used panel variables.
  * Plugin interface to export strings (data) for panel/chart
    labels. Net monitor updated to check for exports.
  * Linux nvidia GPU option to use nvclock when nvidia-settings
    fails.
  * Translation updates (de)
  * Bugfixes
* Tue Jun  6 2006 lmichnovic@suse.cz
- Upgrade to version 2.2.9
  * Add battery monitor option to use percent capacity remaining for alerts.
  * Filippo Giunchedi linux.c patch: make sensor code able to read
    apple/pmu's sysfs based sensors.
  * Jindrich Makovicka linux.c patch: subtract the memory allocated to
    slabs from the used memory and add it to the cached value instead.
  * Put multiple instances lock files in /var/lock.
  * Bugfixes: many
  * Translation updates: bg, es, ru.
* Wed May 24 2006 schwab@suse.de                                                                                      
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul 29 2005 ltinkl@suse.cz
- update to 2.2.7 (#99154)
* Tue Apr 12 2005 ltinkl@suse.cz
- update to 2.2.5
* Mon Nov 29 2004 ltinkl@suse.cz
- update to 2.2.4
* Fri Aug  6 2004 ltinkl@suse.cz
- add openssl support (#43454)
* Mon Jul 19 2004 ltinkl@suse.cz
- update to 2.2.2
* Tue Apr 27 2004 ltinkl@suse.cz
- fix build using -fno-strict-aliasing
* Wed Mar  3 2004 ltinkl@suse.cz
- update to 2.1.27
* Tue Feb 24 2004 ltinkl@suse.cz
- update to 2.1.26
* Thu Jan 22 2004 ltinkl@suse.cz
- update to 2.1.25
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Jan  6 2004 ltinkl@suse.cz
- update to 2.1.24
* Wed Dec 17 2003 ltinkl@suse.cz
- update to 2.1.22
* Tue Oct 14 2003 ltinkl@suse.cz
- update to 2.1.21
* Thu Oct  9 2003 ltinkl@suse.cz
- updated to version 2.1.20
* Tue Sep 30 2003 ltinkl@suse.cz
- updated to 2.1.19
- cleaned up the requires and neededforbuild
- look for translations in the right directory
* Thu Sep  4 2003 ltinkl@suse.cz
- update to 2.1.16, also fixes #29628
* Sat Aug 16 2003 adrian@suse.de
- add desktop file
* Thu Jun 19 2003 ltinkl@suse.cz
- fixed manpage installation
* Wed Jun 11 2003 ltinkl@suse.cz
- fixed to install to /usr
* Mon Jun  9 2003 ltinkl@suse.cz
- updated sources to version 2.1.12
- fixed the Makefile patch
- install gkrellm.pc
* Wed Jan 15 2003 ro@suse.de
- use gtk2-devel-packages in neededforbuild
- fix a lib64 issue
* Sat Jan 11 2003 tcrhak@suse.cz
- update to version 2.1.5
* Wed Jul  3 2002 tcrhak@suse.cz
- update to version 1.2.13
* Fri Mar 15 2002 tcrhak@suse.cz
- added /usr/X11R6/include/%%{name} to filelist
* Thu Dec 20 2001 tcrhak@suse.cz
- update to version 1.2.6
* Tue Aug  7 2001 adostal@suse.cz
- update to version 1.2.1
- fixed spec file  and makefile
* Thu Feb 15 2001 egger@suse.de
- Updated to version 1.0.6.
* Wed Jan 10 2001 ro@suse.de
- fixed doc list
* Mon Nov  6 2000 ro@suse.de
- fixed neededforbuild
* Sun Oct 15 2000 egger@suse.de
- Updated to version 1.0.0.
* Fri Jun  9 2000 dipa@suse.de
- update to package 0.9.10
* Sat Oct 30 1999 ray@suse.de
- nwe packages 0.7.1
